@@ -150,6 +150,9 @@ extern crate diesel_migrations;
 #[cfg(feature = "diesel-support")]
 pub mod schema;
 
+#[cfg(feature = "sql")]
+pub mod sql_support;
+
 /// Generates a random salt, this is automatically done when
 /// creating a user.
 pub fn salt() -> String {
