@@ -4,15 +4,13 @@ use core::fmt;
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
-#[cfg(feature = "diesel-support")]
-pub mod diesel_support;
 
 /// The User struct stores information about an
 /// individual login.
 ///
 /// It support serde and so can be serialized to, for example, json or
 /// toml. For diesel support you can convert it to a
-/// [DieselUser](user::diesel_support::DieselUser), which intern supports
+/// [SqlUser](user::diesel_support::SqlUser), which intern supports
 /// `Queryable`, `Insertable`, and `Identifiable`.
 #[derive(Clone, Debug, Hash, PartialEq, Eq, Ord, PartialOrd)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
